@@ -97,16 +97,16 @@ xl_read_pivot_cache (XLPivotReadState *s, BiffQuery *q)
 		guint16 stream_id	= GSF_LE_GET_GUINT16 (q->data + 4);
 		guint16 flags		= GSF_LE_GET_GUINT16 (q->data + 6);
 		guint16 rec_per_block	= GSF_LE_GET_GUINT16 (q->data + 8);	/* seems constant */
-		guint16 base_fields 	= GSF_LE_GET_GUINT16 (q->data + 10);	/* base */
+		guint16 base_fields	= GSF_LE_GET_GUINT16 (q->data + 10);	/* base */
 		/* guint16 zero */
 		guint16 type		= GSF_LE_GET_GUINT16 (q->data + 16);
 		char *who		= excel_get_text (s->importer,
 			q->data + 20, GSF_LE_GET_GUINT16 (q->data + 18), NULL);
 		fprintf (stderr, "num_rec = %u;\nstream_id = %hu;\n"
 			 "rec per block = %hu;\nbase fields = %hu;\ntotal fields = %hu;\n"
-			 "last modified by = '%s';\n",
+			 "last modified by = '%s';type = 0x%x, flags = 0x%x;\n",
 			 s->num_records, stream_id, rec_per_block, base_fields,
-			 s->num_fields, who);
+			 s->num_fields, who, type, flags);
 		g_free (who);
 	});
 
@@ -159,7 +159,7 @@ xl_read_pivot_cache (XLPivotReadState *s, BiffQuery *q)
 			fprintf (stderr, "FIELD [%d] '%s' has %d items, %d grouped items, and flags = 0x%hx;\n",
 				s->cur_field, name, s->num_items, child_group, flags);
 			g_free (name);
-			
+
 #if 0
 			d (4, gsf_mem_dump (q->data + 2, MIN (q->length, 0xc)););
 
@@ -293,6 +293,8 @@ excel_read_pivot_caches (GnmXLImporter *importer,
 	BiffQuery *q;
 	GsfInput  *cache, *dir;
 
+	return;
+
 	if (NULL == ole)
 		return;				/* pre-Excel 95 without ole */
 	dir = gsf_infile_child_by_name (ole, "_SX_DB_CUR");	/* Excel 97 */
@@ -301,8 +303,6 @@ excel_read_pivot_caches (GnmXLImporter *importer,
 	if (NULL == dir)
 		return;
 
-	return; /* leave this disabled for now */
-
 	s.importer = importer;
 	n = gsf_infile_num_children (GSF_INFILE (dir));
 	for (i = 0 ; i < n ; i++) {
