@@ -1,10 +1,13 @@
-#ifndef GNM_FORMAT_H
-#define GNM_FORMAT_H
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+#ifndef _GNM_FORMAT_H_
+# define _GNM_FORMAT_H_
 
 #include "gnumeric.h"
 #include <goffice/utils/go-format.h>
 #include <pango/pango.h>
 
+G_BEGIN_DECLS
+
 char  *format_value	    (GOFormat const *format,
 			     GnmValue const *value, GOColor *go_color,
 			     int col_width,
@@ -34,8 +37,8 @@ int gnm_format_is_date_for_value (GOFormat const *fmt,
 int gnm_format_is_time_for_value (GOFormat const *fmt,
 				  GnmValue const *value);
 
-gboolean gnm_format_month_before_day (GOFormat const *fmt,
-				      GnmValue const *value);
+int gnm_format_month_before_day (GOFormat const *fmt,
+				 GnmValue const *value);
 
 gboolean gnm_format_has_hour (GOFormat const *fmt,
 			      GnmValue const *value);
@@ -59,4 +62,6 @@ gboolean gnm_format_has_hour (GOFormat const *fmt,
 
 
 
-#endif /* GNM_FORMAT_H */
+G_END_DECLS
+
+#endif /* _GNM_FORMAT_H_ */
