@@ -1,6 +1,7 @@
 #include <gnumeric-config.h>
 
 #include "gnm-graph-window.h"
+#include "application.h"
 
 #include <string.h>
 
@@ -267,12 +268,18 @@ gnm_graph_window_set_graph (GnmGraphWindow *window,
 	}
 
 	if (graph != NULL) {
-		window->graph = go_graph_widget_new (graph);
+		graph = gog_graph_dup (graph);
+		window->graph = g_object_new (GO_GRAPH_WIDGET_TYPE,
+					      "graph", graph,
+					      "hres", gnm_app_display_dpi_get (TRUE),
+					      "vres", gnm_app_display_dpi_get (FALSE),
+					      NULL);
+		g_object_unref (graph);
 		gtk_widget_show (window->graph);
 		gtk_container_add (GTK_CONTAINER (window->scrolled_window), window->graph);
 
 		gtk_widget_size_request (window->toolbar, &toolbar_requisition);
-		gtk_window_set_default_size (GTK_WINDOW (window), 
+		gtk_window_set_default_size (GTK_WINDOW (window),
 					     (int) graph_width,
 					     (int) graph_height + toolbar_requisition.height);
 
@@ -292,6 +299,8 @@ gnm_graph_window_new (GogGraph *graph,
 {
 	GtkWidget *ret;
 
+	g_return_val_if_fail (IS_GOG_GRAPH (graph), NULL);
+
 	ret = g_object_new (gnm_graph_window_get_type (), NULL);
 	gnm_graph_window_set_graph (GNM_GRAPH_WINDOW (ret), graph, graph_width, graph_height);
 
