@@ -32,6 +32,8 @@
 #include "stf-parse.h"
 
 #include "workbook.h"
+#include "cell.h"
+#include "sheet.h"
 #include "clipboard.h"
 #include "sheet-style.h"
 #include "value.h"
@@ -41,10 +43,13 @@
 #include "parse-util.h"
 #include <goffice/utils/datetime.h>
 #include <goffice/utils/go-glib-extras.h>
+#include <goffice/utils/go-locale.h>
 #include <goffice/utils/go-format.h>
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <locale.h>
+#include <string.h>
 
 #define SETUP_LOCALE_SWITCH char *oldlocale = NULL
 
@@ -313,8 +318,8 @@ stf_parse_options_csv_set_stringindicator (StfParseOptions_t *parseoptions, guni
 /**
  * stf_parse_options_csv_set_indicator_2x_is_single:
  * @indic_2x : a boolean value indicating whether we want to see two
- * 		adjacent string indicators as a single string indicator
- * 		that is part of the cell, rather than a terminator.
+ *		adjacent string indicators as a single string indicator
+ *		that is part of the cell, rather than a terminator.
  **/
 void
 stf_parse_options_csv_set_indicator_2x_is_single (StfParseOptions_t *parseoptions,
@@ -587,6 +592,10 @@ stf_parse_csv_cell (GString *text, Source_t *src, StfParseOptions_t *parseoption
 		if ((parseoptions->trim_spaces & TRIM_TYPE_LEFT) == 0)
 			break;
 
+		if (stf_parse_csv_is_separator (cur, parseoptions->sep.chr,
+						parseoptions->sep.str))
+			break;
+
 		if (!g_unichar_isspace (g_utf8_get_char (cur)))
 			break;
 		cur = g_utf8_next_char (cur);
@@ -680,8 +689,10 @@ stf_parse_csv_line (Source_t *src, StfParseOptions_t *parseoptions)
 
 	while (1) {
 		GString *text = g_string_sized_new (30);
-
-		switch (stf_parse_csv_cell (text, src, parseoptions)) {
+		StfParseCellRes res =
+			stf_parse_csv_cell (text, src, parseoptions);
+		trim_spaces_inplace (text->str, parseoptions);
+		switch (res) {
 		case STF_CELL_FIELD_NO_SEP:
 			g_ptr_array_add (line, g_string_free (text, FALSE));
 			cont = FALSE;
@@ -726,7 +737,7 @@ stf_parse_fixed_cell (Source_t *src, StfParseOptions_t *parseoptions)
 
 	while (*cur != 0 && !compare_terminator (cur, parseoptions) && splitval != src->linepos) {
 		src->linepos++;
-	        cur = g_utf8_next_char (cur);
+		cur = g_utf8_next_char (cur);
 	}
 
 	res = g_string_chunk_insert_len (src->chunk,
@@ -1331,13 +1342,13 @@ stf_parse_options_guess (char const *data)
 	GPtrArray *lines;
 	int tabcount;
 	int sepcount;
-	gunichar sepchar = format_get_arg_sep ();
+	gunichar sepchar = go_locale_get_arg_sep ();
 
 	g_return_val_if_fail (data != NULL, NULL);
 
 	res = stf_parse_options_new ();
 	lines_chunk = g_string_chunk_new (100 * 1024);
-	lines = stf_parse_lines (res, lines_chunk, data, SHEET_MAX_ROWS, FALSE);
+	lines = stf_parse_lines (res, lines_chunk, data, 1000, FALSE);
 
 	tabcount = count_character (lines, '\t', 0.2);
 	sepcount = count_character (lines, sepchar, 0.2);
@@ -1357,7 +1368,7 @@ stf_parse_options_guess (char const *data)
 		 * could very easily occur in text are put last.
 		 */
 		if (count_character (lines, (c = sepchar), 0.5) > 0 ||
-		    count_character (lines, (c = format_get_col_sep ()), 0.5) > 0 ||
+		    count_character (lines, (c = go_locale_get_col_sep ()), 0.5) > 0 ||
 		    count_character (lines, (c = ':'), 0.5) > 0 ||
 		    count_character (lines, (c = ','), 0.5) > 0 ||
 		    count_character (lines, (c = ';'), 0.5) > 0 ||
