@@ -7,9 +7,10 @@
 #include "io-context-gtk.h"
 /* TODO: Get rid of this one */
 #include "command-context-stderr.h"
-#include "workbook-control-gui.h"
+#include "wbc-gtk.h"
 #include "workbook-view.h"
 #include <goffice/app/go-plugin.h>
+#include <goffice/app/go-doc.h>
 #include "selection.h"
 #include "sheet-view.h"
 #include "commands.h"
@@ -21,13 +22,11 @@
 #include <goffice/app/io-context.h>
 
 #include <gtk/gtkmain.h>
-#ifdef WITH_GNOME
+#ifdef GNM_WITH_GNOME
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-ui-main.h>
 #endif
 
-int gnumeric_no_splash = TRUE;
-
 #define TEST_STEPS	50
 #define STEP_SIZE	40
 
@@ -58,36 +57,37 @@ cb_exercise_pango (gpointer data)
 }
 
 int
-main (int argc, char **argv)
+main (int argc, char const **argv)
 {
 	GOCmdContext *cc;
 	WorkbookControl *wbc;
 	IOContext *ioc;
 
-	gnm_pre_parse_init (argv[0]);
+	argv = gnm_pre_parse_init (argc, argv);
 	gtk_init (&argc, &argv);
-	gnm_common_init (FALSE);
+	gnm_init (FALSE);
 
 	cc  = cmd_context_stderr_new ();
 	ioc = gnumeric_io_context_new (cc);
 	g_object_unref (cc);
 
- 	gnm_plugins_init (GO_CMD_CONTEXT (ioc));
+	gnm_plugins_init (GO_CMD_CONTEXT (ioc));
 	g_object_unref (ioc);
 
 	initial_workbook_open_complete = TRUE; /* make the last unref exit */
 
-	wbc = workbook_control_gui_new (NULL, workbook_new_with_sheets (1), NULL);
+	wbc = wbc_gtk_new (NULL, workbook_new_with_sheets (1), NULL, NULL);
 
 	g_idle_add (cb_exercise_pango, wbc);
 
-#ifdef WITH_GNOME
+#ifdef GNM_WITH_GNOME
 	bonobo_main ();
 #else
 	gtk_main ();
 #endif
 
 	gnm_shutdown ();
+	gnm_pre_parse_shutdown ();
 
 	return 0;
 }
