@@ -137,6 +137,8 @@ sub test_sheet_calc {
     my $pargs = (ref $_[0]) ? shift @_ : [];
     my ($range,$expected) = @_;
 
+    &report_skip ("file $file does not exist") unless -r $file;
+
     my $tmp = fileparse ($file);
     $tmp =~ s/\.[a-zA-Z0-9]+$/.csv/;
     &junkfile ($tmp);
@@ -272,7 +274,7 @@ sub test_valgrind {
     $cmd = "--leak-check=full $cmd";
     $cmd = "--num-callers=20 $cmd";
     $cmd = "--track-fds=yes $cmd";
-    $cmd = "--log-file-exactly=$outfile $cmd";
+    $cmd = "--log-file=$outfile $cmd";
     $cmd = "valgrind $cmd";
     $cmd = "../libtool --mode=execute $cmd" if $uselibtool;
 
@@ -352,9 +354,21 @@ sub test_ssindex {
     }
 }
 
+# -----------------------------------------------------------------------------
+
+sub report_skip {
+    my ($txt) = @_;
+
+    print "SKIP -- $txt\n";
+    # 77 is magic for automake
+    exit 77;
+}
+
 # -----------------------------------------------------------------------------
 # Setup a consistent environment
 
+&report_skip ("all tests skipped") if exists $ENV{'GNUMERIC_SKIP_TESTS'};
+
 delete $ENV{'G_SLICE'};
 $ENV{'G_DEBUG'} = 'fatal_criticals';
 
